==> camitk_3.2.2.orig.tar.gz: camitk-3.2.2-Source/sdk/libraries/core/viewer/PropertyExplorer.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2013 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef PROPERTYEXPLORER_H
#define PROPERTYEXPLORER_H

// -- Core stuff
#include "Viewer.h"
#include "ObjectController.h"
#include "ActionViewer.h"

// -- QT stuff
#include <qteditorfactory.h>
#include <QtTreePropertyBrowser>
#include <QtButtonPropertyBrowser>
#include <QtGroupBoxPropertyBrowser>

// -- QT stuff classes
class QTabWidget;
class QPushButton;

namespace camitk {


class ObjectController;

/** The property explorer.
 *
 * The property explorer is a special container, placed generally
 * bellow the explorer. It has a default tab (property editor) and can
 * include any number of other tabs (where you can, of course, have any kind of widgets
 * you want: slider, labels, text, ...).
 *
 * The property editor is a "magic" widget (aka as "poOOowerful" widget)
 * that use QObject derived class and build a property editor UI.
 * It is presented as a list (automatically build from your QObject derived class
 * Q_PROPERTY):
 * - first column is the property name,
 * - second column is the editing widgets (where the user can interactively change
 *   the property value).
 *
 * \note
 * When your property editor has modified something
 * in the Component that can change the way it is viewed/rendered by one or
 * all of the Component viewers, you have to call the Component's method refresh()...
 *
 * See also ObjectController documentation for more informations and a complete example.
 *
 * This viewer also manages a singleton (THE CamiTK PropertyExplorer). See getInstance() for more information.
 * You do not have to use it, but it is convienent (and sometimes preferable) to use this instance
 * instead of creating your own one.
 * 
 * @see ObjectController
 */
class CAMITK_API PropertyExplorer : public Viewer {
    Q_OBJECT
    Q_ENUMS(camitk::ObjectController::ViewMode); // so that it can be used in property editor
    Q_PROPERTY(camitk::ObjectController::ViewMode viewMode READ getViewMode WRITE setViewMode);

public:
    /** @name General
      */
    ///@{
    /// constructor
    PropertyExplorer();

    /// destructor
    virtual ~PropertyExplorer();

        /// returns the unique instance of ActionViewer
    static PropertyExplorer* getInstance();
    ///@}
    
    /** @name Inherited from Viewer
      */
    ///@{
    /// returns the number of Component that are displayed by this viewer
    virtual unsigned int numberOfViewedComponent();

    /// refresh the property editor
    virtual void refresh(Viewer *whoIsAsking = NULL);

    /// get the viewer widget. @param parent the parent widget for the viewer widget
    virtual QWidget * getWidget(QWidget * parent = NULL);

    /// add a property to change the ObjectController representation at run-time (user choice)
    virtual QObject * getPropertyObject();
    ///@}

    /** @name Manage View mode (user preference)
      */
    ///@{
    /// get the current view mode
    const ObjectController::ViewMode getViewMode();

    /// set the view mode
    void setViewMode(ObjectController::ViewMode);
    ///@}
    
private:
    
    /// the widgets
    ObjectController *theController;
    QTabWidget *tabWidget;
    QPushButton *revertButton;
    QPushButton *applyButton;

    /// the viewed Component
    Component *currentComponent;


    /** clear all the additional widgets, reset currentComponent (and update its visibility).
      * \note this method does not delete the different widgets that were included in the tabs, the Component should do it.
      */
    void clear();
};
}
#endif

==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/libraries/core/viewer/PropertyExplorer.h <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2014 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/
#ifndef PROPERTYEXPLORER_H
#define PROPERTYEXPLORER_H

// -- Core stuff
#include "Viewer.h"
#include "ObjectController.h"
#include "ActionViewer.h"

// -- QT stuff
#include <qteditorfactory.h>
#include <QtTreePropertyBrowser>
#include <QtButtonPropertyBrowser>
#include <QtGroupBoxPropertyBrowser>

// -- QT stuff classes
class QTabWidget;
class QPushButton;

namespace camitk {


class ObjectController;

/** 
 * @ingroup group_sdk_libraries_core_viewer
 * 
 * @brief
 * The property explorer.
 *
 * The property explorer is a special container, placed generally
 * bellow the explorer. It has a default tab (property editor) and can
 * include any number of other tabs (where you can, of course, have any kind of widgets
 * you want: slider, labels, text, ...).
 * 
 * \image html libraries/propertyexplorer.png "The property explorer viewer."
 *
 * The property editor is a "magic" widget (aka as "poOOowerful" widget)
 * that use QObject derived class and build a property editor UI.
 * It is presented as a list (automatically build from your QObject derived class
 * Q_PROPERTY):
 * - first column is the property name,
 * - second column is the editing widgets (where the user can interactively change
 *   the property value).
 *
 * \note
 * When your property editor has modified something
 * in the Component that can change the way it is viewed/rendered by one or
 * all of the Component viewers, you have to call the Component's method refresh()...
 *
 * See also ObjectController documentation for more informations and a complete example.
 *
 * This viewer also manages a singleton (THE CamiTK PropertyExplorer). See getInstance() for more information.
 * You do not have to use it, but it is convienent (and sometimes preferable) to use this instance
 * instead of creating your own one.
 * 
 * @see ObjectController
 */
class CAMITK_API PropertyExplorer : public Viewer {
    Q_OBJECT
    Q_ENUMS(camitk::ObjectController::ViewMode); // so that it can be used in property editor
    Q_PROPERTY(camitk::ObjectController::ViewMode viewMode READ getViewMode WRITE setViewMode);

public:
    /** @name General
      */
    ///@{
    /// constructor
    PropertyExplorer();

    /// destructor
    virtual ~PropertyExplorer();

        /// returns the unique instance of ActionViewer
    static PropertyExplorer* getInstance();
    ///@}
    
    /** @name Inherited from Viewer
      */
    ///@{
    /// returns the number of Component that are displayed by this viewer
    virtual unsigned int numberOfViewedComponent();

    /// refresh the property editor
    virtual void refresh(Viewer *whoIsAsking = NULL);

    /// get the viewer widget. @param parent the parent widget for the viewer widget
    virtual QWidget * getWidget(QWidget * parent = NULL);

    /// add a property to change the ObjectController representation at run-time (user choice)
    virtual QObject * getPropertyObject();
    ///@}

    /** @name Manage View mode (user preference)
      */
    ///@{
    /// get the current view mode
    const ObjectController::ViewMode getViewMode();

    /// set the view mode
    void setViewMode(ObjectController::ViewMode);
    ///@}
    
private:
    
    /// the widgets
    ObjectController *theController;
    QTabWidget *tabWidget;
    QPushButton *revertButton;
    QPushButton *applyButton;

    /// the viewed Component
    Component *currentComponent;


    /** clear all the additional widgets, reset currentComponent (and update its visibility).
      * \note this method does not delete the different widgets that were included in the tabs, the Component should do it.
      */
    void clear();
};
}
#endif
